.waf--html-field-wrapper,.waf--submit-btn-container{margin-top:2rem}.waf--field-container{margin-top:2rem}.waf--field-container input[type=date],.waf--field-container input[type=email],.waf--field-container input[type=number],.waf--field-container input[type=text],.waf--field-container input[type=text],.waf--field-container input[type=url],.waf--field-container select,.waf--field-container textarea{display:block;padding:1.5rem;border-radius:4px;width:100%;border:1px solid #e5e5e5}.waf--field-container .waf--field-label{font-size:2rem}.waf--field-container .waf--field-help-text{font-size:1rem;opacity:0.8}.waf--field-container .waf--choice-inline{display:inline;margin-right:50px}.waf--field-container .waf--radio-list{list-style:none;margin-left:0;padding-left:0}.waf--field-container .waf--field-label-choice{padding-left:10px}.waf--field-container--error input[type=date],.waf--field-container--error input[type=email],.waf--field-container--error input[type=number],.waf--field-container--error input[type=text],.waf--field-container--error input[type=text],.waf--field-container--error input[type=url],.waf--field-container--error select,.waf--field-container--error textarea{border-color:#f24949}.waf--submit-btn{padding:1rem 2rem}.waf--field-error{color:#f24949;font-size:1rem;margin-top:0.5rem}

